<?xml version="1.0" encoding="iso-8859-1"?>

<!-- CONTACT : formatage des donnees XML vers un affichage HTML
 
 Bertrand Le Quellec (c) 2011-2021
 
 Version: 1.8 - Cree: 2011-09-20
 
 Modifie: 2021-10-03
 Modifie: 2013-12-02
 Modifie: 2013-12-20 - gestion adresse sans type
 Modifie: 2014-05-16 - ajout liens sur telephone
 Modifie: 2014-06-19 - ajout liens sur emails
 Modifie: 2014-09-25 - ajout liste de l'historique et feuille de style de base
 Modifie: 2014-10-21 - suppression feuille de style de base par des valeurs globales
 Modifie: 2014-11-30 - ajout style sur la dimension du logo affiche
 Modifie: 2016-03-20 - prise en charge des labels des statuts sur Historique-Evenement
 
 Description:
 Fichier Xsl de formatage d'un fichier Xml generique de donnees d'un objet unique Xml
 representant la structure d'un Client/Contact.
 -->

<xsl:stylesheet id="stylesheet" version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <!-- Declarations des variables designant les parametres de la Page. -->  
  <xsl:variable name="margin"              select="'2px'" />
  <xsl:variable name="padding"             select="'5px'" />
  <xsl:variable name="background_color"    select="'#F4FAFC'" />
  <xsl:variable name="font_size"           select="'75%'" />
  <xsl:variable name="font_family"         select="'Verdana, Geneva, Tahoma, sans-serif'" />
  
  <!-- Declarations des variables designant les couleurs. -->
  <xsl:variable name="legendtop_color"     select="'Lavender'" />
  <xsl:variable name="legendleft_color"    select="'#B8CCEE'" />
  <xsl:variable name="rowseparator_color"  select="'Black'" />
  <xsl:variable name="content_color"       select="'#B8CCDC'" />
  <xsl:variable name="comment_color"       select="'#ffebcd'" />
  <xsl:variable name="actionleft_color"    select="'lightgrey'" />

  <!-- Declarations des variables designant le formatage des principaux tableaux. -->
  <xsl:variable name="table_color"         select="'#ffffff'" />
  <xsl:variable name="table_border"        select="'0'" />
  <xsl:variable name="table_spacing"       select="'1'" />
  <xsl:variable name="table_padding"       select="'0'" />
  <xsl:variable name="table_font"          select="'normal serif'" />
  
   <!-- Declarations des variables designant le formatage des tableaux secondaires. -->
  <xsl:variable name="table2_color"         select="'#ffffff'" />
  <xsl:variable name="table2_border"        select="'0'" />
  <xsl:variable name="table2_spacing"       select="'1'" />
  <xsl:variable name="table2_padding"       select="'0'" />
  
  <!-- La methode de formatage du resultat html -->
  <xsl:output
   method="html"
   encoding="ISO-8859-1"
   doctype-public="-//W3C//DTD HTML 4.01//EN"
   doctype-system="http://www.w3.org/TR/html4/strict.dtd"
   indent="yes" />

  <!-- Corps du resultat HTML : point de depart -->
  <xsl:template match="/">
    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="fr">

      <head>
        <title>
          <xsl:value-of disable-output-escaping="yes" select="Contact/Contact/Firstname" /> <xsl:value-of disable-output-escaping="yes" select="Contact/Contact/Lastname" />
        </title>
        <meta name="description" content="Contact Manager - Contact" />

        <meta name="publisher" content="BLQ software" />
        <meta name="author" content="BLQ software" />
        <meta name="copyright" content="BLQ software" />

        <meta name="http.language" content="French" />
        <meta name="Language" content="FR,BE,CH" />
        <meta http-equiv="Content-Language" content="fr,be,ch" />
      </head>

      <body style="margin:{$margin}; padding:{$padding}; background-color:{$background_color}; font-size:{$font_size}; font-family:{$font_family}; ">
        <!-- *********************************************
            Traitement de la racine Xml nommee Contact 
           ********************************************* -->
        <xsl:apply-templates select="Contact" />
      </body>
    </html>
  </xsl:template>

  <!-- 
   ===========================================
   CONTACT : premier niveau de traitement Xml 
   =========================================== -->
  <xsl:template match="Contact">

    <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <tr>
        <th width="40%" align="left">
          <font size="+1">
            <b>
              <xsl:choose>
                <xsl:when test="Contact/Rank= '4'">
                  <xsl:text>* * * *</xsl:text>
                </xsl:when>
                <xsl:when test="Contact/Rank= '3'">
                  <xsl:text>* * *</xsl:text>
                </xsl:when>
                <xsl:when test="Contact/Rank= '2'">
                  <xsl:text>* *</xsl:text>
                </xsl:when>
                <xsl:when test="Contact/Rank= '1'">
                  <xsl:text>*</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <!-- Insertion d'un espace -->
                  <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </b>
          </font>
        </th>

        <!-- DATE DE CREATION -->
        <th align="right">
          <font size="-2">
            <i>
              cree le
              <xsl:value-of select="@created" />
            </i>
          </font>
        </th>

        <!-- DATE DE MODIFICATION -->
        <th align="right">
          <font size="-2">
            <i>
              modifie le
              <xsl:value-of select="@changed" />
            </i>
          </font>
        </th>
      </tr>
    </table>

    <!-- ======================================================================= -->
    <!-- Tableau d'affichage des infos principales : NOM et NOTE -->
    <p>
    <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <tr>

        <!-- CONTACT LASTNAME -->
        <th bgcolor="{$comment_color}">
          <font style="text-transform: uppercase; font-size:large;">
            <xsl:value-of select="Contact/Lastname" />
          </font>
        </th>

        <!-- CONTACT FIRSTNAME -->
        <th bgcolor="{$comment_color}" width="30%">
          <font style="text-transform: capitalize; font-size:large;">
            <xsl:value-of select="Contact/Firstname" />
          </font>
        </th>
      </tr>

      <!-- == ... ======================================================================= -->
      <!-- NOTE -->
      <tr>
        <!-- boucle sur les Lignes de la Note -->
        <th valign="top" align="left">
          <code>
            <xsl:for-each select="Contact/Notes">
              <xsl:apply-templates select="Item" />
            </xsl:for-each>
          </code>
        </th>

        <!-- LOGO & WEB SITE -->
        <th valign="top" width="30%">
          <!-- LOGO -->
          <xsl:if test = "normalize-space(Contact/Logo)">
            <img src="{Contact/Logo}" style="width:150px; height:150px;" />
            <!-- Ajout retour e la ligne si lien Web apres le logo -->
            <xsl:if test = "normalize-space(Contact/Web)">
              <br />
            </xsl:if>
          </xsl:if>

          <!-- WEB SITE -->
          <xsl:if test = "normalize-space(Contact/Web)">
            <a href="{Contact/Web}" target="_blank">
              <xsl:value-of select="Contact/Web" />
            </a>
          </xsl:if>
        </th>
      </tr>

      <!-- Fermeture du tableau Html -->
    </table>
    </p>
    
    <!-- == ADRESSE =======================================================================  -->
    <xsl:choose>
      <!-- The array of addresses will contain data -->
      <xsl:when test="count(Contact/Addresses/Address) > 0">
        <xsl:if test="Contact/Addresses/Address[@key] != ''">
        <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
          <tr>
            <th width="100%" valign="top">
                <br />
                <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
                  <tr>
                    <th colspan="4" align="center" bgcolor="{$legendleft_color}">
                      <font style="text-transform: capitalize; font-size:large; font-weight: bold;">adresses</font>
                    </th>
                  </tr >

                  <!-- == SEPARATEUR =============================================================== -->
                  <tr>
                    <th bgcolor="{$rowseparator_color}" colspan="4"></th>
                  </tr>

                  <!-- == ... ======================================================================= -->
                  <!-- Boucle sur la liste des Adresses du fichier Xml -->
                  <xsl:for-each select="Contact/Addresses">
                    <xsl:apply-templates select="Address" />
                  </xsl:for-each>
                  <!-- Fermeture du tableau Html des Adresses-->
                </table >
            </th>
            <!-- == ... ======================================================================= -->
          </tr>
        </table> 
        </xsl:if>          
    </xsl:when>
  </xsl:choose>

    <p>
    <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <tr>
        <!-- 2 ===> Tableau d'affichage des Emails <=== -->
        <th valign="top">
          <!-- Test le nombre de sous Nodes, car seules les informations non vides sont e traiter -->
          <xsl:choose>
            <xsl:when test="count(Contact/Emails/Email) > 0">
              <!-- Le tableau des emails contiendra des donnees -->
              <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
                <tr>
                  <th colspan="2" align="center" bgcolor="{$legendleft_color}">
                    <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                        <xsl:text disable-output-escaping="yes">emails</xsl:text>
                    </font>
                  </th>
                </tr >

                <!-- Boucle sur la liste des emails du fichier Xml -->
                <xsl:for-each select="Contact/Emails">
                  <xsl:apply-templates select="Email" />
                </xsl:for-each>
                <!-- Fermeture du tableau Html des telephones -->
              </table >
            </xsl:when>

            <xsl:when test="count(Contact/Emails/Email)= 0">
              <!-- Insertion d'un espace e la place du tableau vide des emails -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:when>
          </xsl:choose>
        </th>
        <!-- == END EMAILS ==================================================================== -->

        <!-- 3 ===> Tableau d'affichage des Telephones <=== -->
        <th valign="top">
          <!-- Test le nombre de sous Nodes, car seules les informations non vides sont e traiter -->
          <xsl:choose>
            <xsl:when test="count(Contact/Phones/Phone) > 0">
              <!-- Le tableau des telephones contiendra des donnees -->
              <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
                <tr>
                  <th colspan="2" align="center" bgcolor="{$legendleft_color}">
                    <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                        <xsl:text disable-output-escaping="yes">t&amp;eacute;l&amp;eacute;phones</xsl:text>
                    </font>
                  </th>
                </tr >

                <!-- Boucle sur la liste des telephones du fichier Xml -->
                <xsl:for-each select="Contact/Phones">
                  <xsl:apply-templates select="Phone" />
                </xsl:for-each>
                <!-- Fermeture du tableau Html des telephones -->
              </table >
            </xsl:when>

            <xsl:when test="count(Contact/Phones/Phone)= 0">
              <!-- Insertion d'un espace e la place du tableau vide des telephones -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:when>
          </xsl:choose>
        </th>
        <!-- == END PHONES ==================================================================== -->
      </tr>
    </table>
    </p>
    
    <!-- 4 ===> Tableau d'affichage des Champs personnalises <=== -->
    <!-- Test le nombre de sous Nodes, car seules les informations non vides sont e traiter -->
    <xsl:if test="count(Contact/Customs/Custom) > 0">
      <p>
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
        <tr>
          <th colspan="2" align="left" bgcolor="{$legendleft_color}">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                <xsl:text disable-output-escaping="yes">informations compl&amp;eacute;mentaires</xsl:text>
            </font>
          </th>
        </tr >

        <!-- Boucle sur la liste des Customs du fichier Xml -->
        <xsl:for-each select="Contact/Customs">
          <xsl:apply-templates select="Custom" />
        </xsl:for-each>
        <!-- Fermeture du tableau Html des Customs -->
      </table >
      </p>
    </xsl:if>

    <!-- 5 ===> Tableau d'affichage des Collegues <=== -->
    <!-- Test le nombre de sous Nodes, car seules les informations non vides sont e traiter -->
    <xsl:if test="count(Professional/Colleagues/Colleague) > 0">
      <p>
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
        <tr>
          <th align="left" bgcolor="{$legendtop_color}">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
              <xsl:text disable-output-escaping="yes">collegues - relations</xsl:text>
            </font>
          </th>
        </tr>
        
        <tr>
          <th style="text-align: center">
            <table bgcolor="{$table_color}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="80%">
              <xsl:for-each select="Professional/Colleagues">
                <xsl:apply-templates select="Colleague"  />
              </xsl:for-each>
            </table >
          </th>
        </tr>
      </table >
      </p>
    </xsl:if>
    
    <!-- 6 ===> Tableau d'affichage des Liens Externes <=== -->
    <!-- Test le nombre de sous Nodes, car seules les informations non vides sont e traiter -->
    <xsl:if test="count(Contact/ExternalLinks/Link) > 0">
      <p>
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
        <tr>
          <th colspan="2" align="left" bgcolor="{$legendtop_color}">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                <xsl:text disable-output-escaping="yes">liens externes</xsl:text>
            </font>
          </th>
        </tr >

        <!-- Boucle sur la liste des Liens Externes du fichier Xml -->
        <xsl:for-each select="Contact/ExternalLinks">
          <xsl:apply-templates select="Link" />
        </xsl:for-each>
        <!-- Fermeture du tableau Html des Liens Externes -->
      </table >
      </p>
    </xsl:if>

    <!-- 7 ===> Tableau d'affichage de l'Historique <=== -->
    <!-- Test le nombre de sous Nodes, car seules les informations non vides sont e traiter -->
    <xsl:if test="count(Historical/History) > 0">
      <p>
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
        <tr>
          <th colspan="3" align="left" bgcolor="{$legendtop_color}">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                <xsl:text disable-output-escaping="yes">historique</xsl:text>
            </font>
          </th>
        </tr >

        <!-- Boucle sur la liste des Historiques du fichier Xml -->
        <xsl:for-each select="Historical">
          <xsl:apply-templates select="History" />
        </xsl:for-each>
        <!-- Fermeture du tableau Html de l'Historique -->
      </table >
      </p>
    </xsl:if>
  </xsl:template>

  <!--
   ==============================================================
   La fonction appellee pour traiter les lignes d'une Note 
   ============================================================== -->
  <xsl:template match="Item">
    <xsl:value-of select="." />
    <br />
  </xsl:template>

  <!--
   ==============================================================
   La fonction appellee pour traiter l'arborescence des Adresses 
   ============================================================== -->
  <xsl:template match="Address">
    <tr>
      <th bgcolor="{$content_color}" align="center">
        <!-- TYPE -->
        <xsl:value-of select="@key" />
      </th>
      <th>
        <!-- STREET -->
        <xsl:value-of select="Street" />
      </th>
      <th width="20%">
        <!-- ZIP/POSTAL CODE -->
        <xsl:value-of select="Zipcode" />
      </th>
      <th width="20%">
        <!-- CITY -->
        <xsl:value-of select="City" />
      </th>
    </tr>

    <!-- Seconde ligne -->
    <tr>
      <th>
        <!-- empty -->
      </th>
      <th>
        <!-- empty -->
      </th>
      <th width="20%">
        <!-- STATE -->
        <xsl:value-of select="State" />
      </th>
      <th width="20%">
        <!-- COUNTRY -->
        <xsl:value-of select="Country" />
      </th>
    </tr>
    <tr>
      <th bgcolor="{$rowseparator_color}" colspan="4"></th>
    </tr>
  </xsl:template>

  <!--
   ================================================================
   La fonction appellee pour traiter l'arborescence des Emails
   Integration de l'appel via un lien URL
   ================================================================ -->
  <xsl:template match="Email">
    <tr>
      <th bgcolor="{$content_color}" align="right">
        <!-- EMAIL TYPE -->
        <xsl:value-of select="Type"/>
        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
      </th>

      <th align="left">
        <!-- DATA + URL -->
        <a href="mailto:{Data}">
          <xsl:value-of select="Data" />
        </a>
      </th>
    </tr>
  </xsl:template>

  <!--
   ================================================================
   La fonction appellee pour traiter l'arborescence des Telephones
   Integration de l'appel via un lien URL
   ================================================================ -->
  <xsl:template match="Phone">
    <tr>
      <th style="text-align:right; background-color:{$content_color}; ">
        <!-- PHONE TYPE -->
        <xsl:value-of select="Type"/>
        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
      </th>

      <th align="left">
        <!-- DATA + URL -->
        <a href="tel:{Data}">
          <xsl:value-of select="Data" />
        </a>
      </th>
    </tr>
  </xsl:template>

  <!--
   ==========================================================================
   La fonction appellee pour traiter l'arborescence des Champs Personnalises 
   ========================================================================== -->
  <xsl:template match="Custom">
    <xsl:if test = "normalize-space(Data)">
      <tr>
        <th bgcolor="{$content_color}" align="right">
          <!-- LABEL -->
          <xsl:value-of select="Label"/>
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </th>

        <th align="left">
          <!-- DATA -->
          <xsl:value-of select="Data" />
        </th>
      </tr>
    </xsl:if>
  </xsl:template>

  <!--
   ==========================================================================
    La fonction appellee pour traiter l'arborescence des Collegues/Relations 
   ========================================================================== -->
  <xsl:template match="Colleague">
    <!--
        DECOUPAGE ETRANGE, MAIS JE N'AI PAS TROUVE MIEUX...
        CETTE PARTIE DE CODE ET D'EXTRACTION DEPUIS UNE CHAINE AVEC SEPARATEUR
        MERITE D'ETRE APPRONFONDIE.
        MAIS EN ATTENDANT D'EN APPRENDRE PLUS SUR CE LANGUAGE ET DE CHERCHER 
        UNE DOCUMENTATION APROPRIEE, ON SE CONTENTE DE CE JEU DE VARIABLES
        -->
    <!-- NOM -->
    <xsl:variable name="item1" select="substring-before(., ']|[')" />
    <xsl:variable name="itemTmp1" select="substring-after(., ']|[')" />
    <!-- TELEPHONE -->
    <xsl:variable name="item2" select="substring-before($itemTmp1, ']|[')" />
    <xsl:variable name="itemTmp2" select="substring-after($itemTmp1, ']|[')" />
    <!-- FONCTION -->
    <xsl:variable name="item3" select="substring-before($itemTmp2, ']|[')" />
    <xsl:variable name="itemTmp3" select="substring-after($itemTmp2, ']|[')" />
    <!-- EMAIL -->
    <xsl:variable name="item4" select="substring-before($itemTmp3, ']|[')" />

    <tr>
      <!-- Alternance des couleurs de fond de chaque ligne  -->
      <xsl:if test="position() mod 2 = 0">
        <xsl:attribute name="bgcolor">lightgrey</xsl:attribute> <!-- 
        En cas de passage d'une couleur incluse dans une variable globale : $actionleft_color
        la couleur visualisee est differente ! Donc la couleur est directement ecrite
        A explorer plus tard... -->
      </xsl:if>
      <th align="left">
        <font style="font-weight: normal;">
          <!-- NOM -->
          <xsl:value-of select="string($item1)" />  
        </font >
      </th>
      <th align="left">
        <a href="tel:{$item2}">
          <!-- TELEPHONE -->
          <xsl:value-of select="string($item2)" />  
        </a>
      </th>
      <th align="left">
        <!-- FONCTION -->
        <xsl:value-of select="string($item3)" />
      </th>
      <th align="left">
        <a href="mailto:{$item4}">
          <!-- EMAIL -->
          <xsl:value-of select="string($item4)" />
        </a>
      </th>
    </tr>
  </xsl:template>
  
  <!--
   =====================================================================
    La fonction appellee pour traiter l'arborescence des Liens Externes 
   ===================================================================== -->
  <xsl:template match="Link">
    <xsl:if test = "normalize-space(Data)">
      <tr>
        <th style="text-align:center; background-color:{$content_color}; ">
          <!-- Category -->
          <xsl:value-of select="LinkCategory" />
        </th>

        <th align="left">
          <!-- DATA : lien effectif sur la donnee -->
          <xsl:choose>
            <!-- Fichier avec acces local -->
            <xsl:when test="@type= 'File'">
              <xsl:if test="normalize-space(Data)">
                <a href="file:///{Data}">
                  <xsl:value-of select="concat(substring-before(Data, '|') ,':', substring-after(Data, '|'))" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Repertoire avec un acces local -->
            <xsl:when test="@type= 'Folder'">
              <xsl:if test="normalize-space(Data)">
                <a href="file:///{Data}">
                  <xsl:value-of select="concat(substring-before(Data, '|') ,':', substring-after(Data, '|'))" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Application executable -->
            <xsl:when test="@type= 'Exe'">
              <xsl:if test="normalize-space(Data)">
                <a href="file:///{Data} {Parameters}" target="_blank">
                  <xsl:value-of select="Data" />
                  <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                  <xsl:value-of select="Parameters" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- URL: Web, FTP, etc. -->
            <xsl:when test="@type= 'Url'">
              <xsl:if test="normalize-space(Data)">
                <a href="{Data}{Parameters}" target="_blank">
                  <xsl:value-of disable-output-escaping="yes" select="Data" />
                  <xsl:value-of disable-output-escaping="yes" select="Parameters" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Email -->
            <xsl:when test="@type= 'Mail'">
              <xsl:if test="normalize-space(Data)">
                <a href="mailto:{Data}">
                  <xsl:value-of select="Data" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Fichier sur une Image -->
            <xsl:when test="@type= 'Image'">
              <xsl:if test="normalize-space(Data)">
                <img src="{Data}" width="100" height="100"/>
              </xsl:if>
            </xsl:when>

            <!-- Fichier sur une Image Web -->
            <xsl:when test="@type= 'ImageWeb'">
              <xsl:if test="normalize-space(Data)">
                <img src="{Data}" />
              </xsl:if>
            </xsl:when>

            <!-- Pas de traitement specifique du lien -->
            <xsl:otherwise>
              <xsl:if test="normalize-space(Data)">
                <xsl:value-of select="Data" />
              </xsl:if>
            </xsl:otherwise>
          </xsl:choose>
        </th>
      </tr >

      <!-- NOTES : un descriptif optionel sur le lien -->
      <xsl:if test = "normalize-space(LinkNotes)">
        <tr>
          <th colspan="2" align="left">
            <code>
              <xsl:value-of select="LinkNotes" />
            </code>
          </th>
        </tr>
      </xsl:if>
    </xsl:if>
  </xsl:template>

  <!--
   ==========================================================================
   La fonction appellee pour traiter l'arborescence des Historiques 
   ========================================================================== -->
  <xsl:template match="History">
    <tr>
      <th style="text-align:center; background-color:{$content_color}; ">
        <!-- DATE -->
        <font size="-1">
          <xsl:value-of select="@date"/>
        </font>
      </th>

      <th align="left">
        <!-- LABEL -->
        <code>
          <xsl:value-of select="Data"/>
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </code>
      </th>

      <th style="text-align:center; background-color:{$comment_color}; ">
        <!-- STATUS -->
        <font style="text-transform: capitalize; font-size:small;">
        <xsl:choose>
          <!-- Old treatment of the data -->
          <xsl:when test="Status= 'unDefined'">indefini</xsl:when>
          <xsl:when test="Status= 'Diferred'">differe</xsl:when>
          <xsl:when test="Status= 'Failed'">echoue</xsl:when>
          <xsl:when test="Status= 'inProgress'">en attente</xsl:when>
          <xsl:when test="Status= 'Pending'">en cours</xsl:when>
          <xsl:when test="Status= 'notStarted'">non demarre</xsl:when>
          <xsl:when test="Status= 'Completed'">termine</xsl:when>
          <xsl:when test="Status= 'neverCompleted'">non termine</xsl:when>
          <!-- New treatment of the data -->
          <xsl:otherwise>
            <xsl:apply-templates select="Status" />
          </xsl:otherwise>
        </xsl:choose>
        </font>
      </th>
    </tr>
  </xsl:template>

  <xsl:template match="Status">
      <xsl:if test="@Label">
        <xsl:value-of select="@Label"/>
      </xsl:if>    
  </xsl:template>

</xsl:stylesheet>



